# Plasmid detect gene feature.  
This is a package developed based on PyO3 for internal use.  
It contains such functions:  

```python 
load_feature  
sequence_search  
align_feature  
align_feature_list  
align_fasta  
load_fasta  
align_seq  
```